<?php
/**
 * DBShop 电子商务系统
 *
 * ==========================================================================
 * @link      https://www.dbshop.net/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbshop.net/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Operation\Service;

use Doctrine\ORM\EntityManager;
use Operation\Entity\CouponCodeRule;

class CouponCodeRuleManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加优惠码生成规则
     * @param array $data
     * @return CouponCodeRule
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addCouponCodeRule(array $data)
    {
        $couponCodeRule = new CouponCodeRule();
        $couponCodeRule->valuesSet($data);
        $couponCodeRule->setCouponCodeRuleAddTime(time());

        $this->entityManager->persist($couponCodeRule);
        $this->entityManager->flush();

        return $couponCodeRule;
    }

    /**
     * 编辑优惠码规则
     * @param array $data
     * @param CouponCodeRule $couponCodeRule
     * @return CouponCodeRule
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function editCouponCodeRule(array $data, CouponCodeRule $couponCodeRule)
    {
        $couponCodeRule->valuesSet($data);
        $this->entityManager->flush();

        return $couponCodeRule;
    }

    /**
     * 删除优惠码规则
     * @param CouponCodeRule $couponCodeRule
     * @return bool
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function deleteCouponCodeRule(CouponCodeRule $couponCodeRule)
    {
        $this->entityManager->remove($couponCodeRule);
        $this->entityManager->flush();

        return true;
    }
}